import 'contentsquare_web_view_controller.dart';
import 'javascript_channel.dart';

/// An object used to track a WebView.
///
/// The three objects of this class must be used: [registerWebViewController],
/// [javascriptChannels], [initializeWebViewTracking].
/// Look at their documentation to know how and when to use them.
abstract class ContentsquareWebViewTracker {
  /// Registers the given [ContentsquareWebViewController] to this tracker.
  ///
  /// WARNING: This method MUST be called BEFORE [initializeWebViewTracking]
  void registerWebViewController(ContentsquareWebViewController controller);

  /// Set of javascript channels to register in the webview
  Set<JavascriptChannel> get javascriptChannels;

  /// Initializes the tracking of the webview.
  ///
  /// WARNING:
  ///   * This method MUST be called AFTER [registerWebViewController]
  ///   * The javascript channel must be available before calling this method.
  Future<void> initializeWebViewTracking();
}
