import 'package:flutter/foundation.dart';
import 'package:webview_flutter/webview_flutter.dart' hide JavascriptChannel;
import 'package:webview_flutter/webview_flutter.dart' as webview_flutter;

import 'models/contentsquare_web_view_controller.dart';
import 'models/contentsquare_web_view_tracker.dart';





@visibleForTesting
String get a245 {
  switch (defaultTargetPlatform) {
    case TargetPlatform.android:
      return 'true';
    case TargetPlatform.iOS:
      return '1';
    default:
      throw Exception('Unknown platform');
  }
}

/// A tracker which maps the [ContentsquareWebViewTracker] to the API of
/// [WebView] from the webview_flutter package.
class ContentsquareFlutterWebViewTracker {
  /// Builds a [ContentsquareFlutterWebViewTracker]
  ContentsquareFlutterWebViewTracker(this._a365);

  
  final ContentsquareWebViewTracker _a365;

  /// Method to use in the [WebView.onWebViewCreated] callback.
  ///
  /// Example:
  /// ```dart
  /// WebView(
  ///   ...
  ///   onWebViewCreated: tracker.onWebViewCreated,
  /// )
  /// ```
  ///
  /// If you need to use the [WebView.onWebViewCreated] callback, you can do
  /// the following:
  /// ```dart
  /// WebView(
  ///   ...
  ///   onWebViewCreated: (controller) {
  ///     tracker.onWebViewCreated(controller);
  ///
  ///     // Do whatever you need to do.
  ///   },
  /// )
  /// ```
  void onWebViewCreated(WebViewController controller) {
    _a365.registerWebViewController(
      ContentsquareWebViewController(
        evaluateJavascript: controller.runJavascriptReturningResult,
        javascriptChannelCall: _a246,
        isChannelAvailable: (channelName) => _a247(
          a520: channelName,
          a521: controller,
        ),
        currentUrl: controller.currentUrl,
      ),
    );
  }

  /// Method to use in the [WebView.onPageFinished] callback.
  ///
  /// Example:
  /// ```dart
  /// WebView(
  ///   ...
  ///   onPageFinished: tracker.onPageFinished,
  /// )
  /// ```
  ///
  /// If you need to use the [WebView.onPageFinished] callback, you can do
  /// the following:
  /// ```dart
  /// WebView(
  ///   ...
  ///   onPageFinished: (url) async {
  ///     await tracker.onPageFinished(url);
  ///
  ///     // Do whatever you need to do.
  ///   },
  /// )
  /// ```
  Future<void> onPageFinished(String url) {
    return _a365.initializeWebViewTracking();
  }

  /// Set of javascript channels to register in the [WebView.javascriptChannels] callback.
  ///
  /// Example:
  /// ```dart
  /// WebView(
  ///   ...
  ///   javascriptChannels: tracker.javascriptChannels,
  /// )
  /// ```
  ///
  /// If you need to add custom javascript channels in the [WebView], you can do
  /// the following:
  /// ```dart
  /// WebView(
  ///   ...
  ///   javascriptChannels: {
  ///      ...tracker.javascriptChannels,
  ///
  ///     // Add you javascript channels.
  ///   },
  /// )
  /// ```
  late final Set<webview_flutter.JavascriptChannel> javascriptChannels = () {
    return _a365.javascriptChannels
        .map(
          (channel) => webview_flutter.JavascriptChannel(
            name: channel.name,
            onMessageReceived: (message) => channel.onMessageReceived(
              message.message,
            ),
          ),
        )
        .toSet();
  }();

  String _a246(String a518, String a519) {
    return 'window.$a518.postMessage($a519)';
  }

  Future<bool> _a247({
    required String a520,
    required WebViewController a521,
  }) async {
    final a366 = await a521.runJavascriptReturningResult(
      _a248(a522: a520),
    );
    return a366 == a245;
  }

  String _a248({
    required String a522,
  }) {
    return '''window.$a522 !== undefined''';
  }
}
